@@ -88,7 +88,7 @@ ObjSelect= function(image, poly){
 	poly = na.omit(poly)
 	
 	# get polygon object
-	poly1 = makepoly( data.frame(x=poly[1:(length(poly)/2)], y=poly[(length(poly)/2 + 1):length(poly)]), 0, TRUE )
+	poly1 = maps:::makepoly( data.frame(x=poly[1:(length(poly)/2)], y=poly[(length(poly)/2 + 1):length(poly)]), 0, TRUE )
 	
 	# return points in polygon... need a vector corresponding to each point...
 	# first allocate two matrices corresponding to X and Y coordinates of the image 
@@ -103,7 +103,7 @@ ObjSelect= function(image, poly){
 	INXY = data.frame(INY,INX) # Must give Y as first vector, then X as second)
 	
 	# Return whether each point is in the polygon, put the matrix structure back
-	IN = matrix(in.polygon(poly1, INXY), nrow = dim(image)[2], ncol = dim(image)[1])
+	IN = matrix(maps:::in.polygon(poly1, INXY), nrow = dim(image)[2], ncol = dim(image)[1])
 	
 	#TODO: Add flow control for b&w v color 
 	
